@@ -1,5 +1,4 @@
 const { fixedEncodeURIComponent, replaceSpaceByUnderscores, isPlainObject } = require('../utils/utils')
-const { isPropertyId } = require('./helpers')
 const wikidataBase = 'https://www.wikidata.org/wiki/'
 const languages = require('./sitelinks_languages')
 
@@ -28,13 +27,22 @@ const siteUrlBuilders = {
   mediawiki: title => `https://www.mediawiki.org/wiki/${title}`,
   meta: wikimediaSite('meta'),
   species: wikimediaSite('species'),
-  wikidata: title => {
-    if (isPropertyId(title)) return `${wikidataBase}Property:${title}`
+  wikidata: entityId => {
+    const prefix = prefixByEntityLetter[entityId[0]]
+    let title = prefix ? `${prefix}:${entityId}` : entityId
+    // Required for forms and senses
+    title = title.replace('-', '#')
     return `${wikidataBase}${title}`
   },
   wikimania: wikimediaSite('wikimania')
 }
 
+const prefixByEntityLetter = {
+  E: 'EntitySchema',
+  L: 'Lexeme',
+  P: 'Property',
+}
+
 const sitelinkUrlPattern = /^https?:\/\/([\w-]{2,10})\.(\w+)\.org\/\w+\/(.*)/
 
 const getSitelinkData = site => {
